==> aomidoro-4.1.tar.gz: aomidoro-4.1/net.h <==
/* $Id: net.h 326 2010-02-13 06:05:38Z ken $ */
/*
 * Copyright (c) 2006 KAMADA Ken'ichi.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

struct sockaddr;
struct timeval;

#ifdef HAVE_SA_LEN
# define SA_LEN(sa) ((sa)->sa_len)
#else
# define SA_LEN(sa) compat_sa_len(sa)
#endif

/*
 * <=== client                                  authoritative server ===>
 *
 *                             qtask
 *                               .servv[].t == tcp <--> tcp transport
 *                                                         .tag = qtask
 *                                          == udp <--> udp transport
 *   udps transport <--- udps == .ct                       .tag = qtask
 *     .tag = (indefinite)
 *   tcp transport  <--> tcp  ==
 *     .tag = qtask
 *   dropped tcp <------ NULL ==
 *   (or spontaneous)
 *
 * - When a qtask is freed in free_qtask(), unpeg the server-side transport
 *   by calling free_transport().  The client-side TCP transport
 *   remains to send a reply; if failed without reply, it remains
 *   untouched so the client may feel annoyed.
 *   The client-side UDP transport is not a per-client, so it is left intact.
 * - When a client-side TCP transport is freed, unpeg the qtask by calling
 *   upcall_drop_tcp_client().  Usually, it is not called because
 *   1) there is not yet a qtask while reading a client socket, and
 *   2) fd_set is cleared in iterative resolution.  It is called only
 *   when the number of max TCP clients exceeds.
 * - When a server-side transport is freed, unpeg the qtask by calling
 *   upcall_drop_server().
 */
struct transport {
	int is_tcp;
	void *tag;
};

int net_init(void);
int net_add_aomidctl(int s);
void inject_sighup(void);
int load_listen_on(const char *addr, const char *port);
int fixate_listen_on(int cancel);
int wait_socket(struct timeval *tvp);
struct transport *open_query(void *tag,
    const struct sockaddr *sa, int use_tcp);
int send_query(struct transport *t, size_t len);
int send_reply(struct transport *t, const struct sockaddr *sa, size_t len);

/* upcall */
int upcall_query(struct transport *t, struct sockaddr *sa,
    char *buf, size_t len);
void upcall_reply(struct transport *t, struct sockaddr *sa,
    char *buf, size_t len);
void upcall_drop_server(struct transport *t);
void upcall_drop_tcp_client(struct transport *t);

size_t upcall_ctl_msg(struct transport *t, char *buf, size_t len);

struct pbuf *get_pbuf_to_query(void);
struct pbuf *get_pbuf_to_reply(struct transport *t);
void free_transport(struct transport *t);

int load_allow_query(const char *addr, int prefixlen);
int fixate_allow_query(int cancel);

struct sockaddr *sadup(const struct sockaddr *sa);
int sacmp(const struct sockaddr *sa1, const struct sockaddr *sa2);
#ifdef NOTUSED
int sadnscmp(const struct sockaddr *sa, int type, const char *addr);
int serv2num(const char *serv);
#endif
const char *sa2str(const struct sockaddr *sa);
const char *addr2str(int family, const char *addr);
struct sockaddr *addr2sa(struct sockaddr *sa, size_t salen,
    unsigned int type, const char *addr);
struct sockaddr *str2sadup(const char *addr);

#ifndef HAVE_SA_LEN
unsigned int compat_sa_len(const struct sockaddr *sa);
#endif

==> aomidoro-4.5.tar.gz: aomidoro-4.5/net.h <==
/* $Id: net.h 382 2015-10-21 13:04:19Z ken $ */
/*
 * Copyright (c) 2006 KAMADA Ken'ichi.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

struct sockaddr;
struct timeval;

#ifdef HAVE_SA_LEN
# define SA_LEN(sa) ((sa)->sa_len)
#else
# define SA_LEN(sa) compat_sa_len(sa)
#endif

/*
 * <=== client                                  authoritative server ===>
 *
 *                             qtask
 *                               .servv[].t == tcp <--> tcp transport
 *                                                         .tag = qtask
 *                                          == udp <--> udp transport
 *   udps transport <--- udps == .ct                       .tag = qtask
 *     .tag = (indefinite)
 *   tcp transport  <--> tcp  ==
 *     .tag = qtask
 *   dropped tcp <------ NULL ==
 *   (or spontaneous)
 *
 * - When a qtask is freed in free_qtask(), unpeg the server-side transport
 *   by calling free_transport().  The client-side TCP transport
 *   remains to send a reply; if failed without reply, it remains
 *   untouched so the client may feel annoyed.
 *   The client-side UDP transport is not a per-client, so it is left intact.
 * - When a client-side TCP transport is freed, unpeg the qtask by calling
 *   upcall_drop_tcp_client().  Usually, it is not called because
 *   1) there is not yet a qtask while reading a client socket, and
 *   2) fd_set is cleared in iterative resolution.  It is called only
 *   when the number of max TCP clients exceeds.
 * - When a server-side transport is freed, unpeg the qtask by calling
 *   upcall_drop_server().
 */
struct transport {
	int is_tcp;
	void *tag;
};

int net_init(void);
int net_add_aomidctl(int s);
void inject_sighup(void);
int load_listen_on(const char *addr, const char *port);
int fixate_listen_on(int cancel);
int wait_socket(struct timeval *tvp);
struct transport *open_query(void *tag,
    const struct sockaddr *sa, int use_tcp);
int send_query(struct transport *t, size_t len);
int send_reply(struct transport *t, const struct sockaddr *sa, size_t len);

/* upcall */
int upcall_query(struct transport *t, struct sockaddr *sa,
    char *buf, size_t len);
void upcall_reply(struct transport *t, struct sockaddr *sa,
    char *buf, size_t len);
void upcall_drop_server(struct transport *t);
void upcall_drop_tcp_client(struct transport *t);

size_t upcall_ctl_msg(struct transport *t, char *buf, size_t len);

struct pbuf *get_pbuf_to_query(void);
struct pbuf *get_pbuf_to_reply(struct transport *t);
void free_transport(struct transport *t);

int load_allow_query(const char *addr, int prefixlen);
int fixate_allow_query(int cancel);

struct sockaddr *sadup(const struct sockaddr *sa);
int sacmp(const struct sockaddr *sa1, const struct sockaddr *sa2);
#ifdef NOTUSED
int sadnscmp(const struct sockaddr *sa, int type, const char *addr);
int serv2num(const char *serv);
#endif
const char *sa2str(const struct sockaddr *sa);
const char *addr2str(unsigned int type, const char *addr);
struct sockaddr *addr2sa(struct sockaddr *sa, size_t salen,
    unsigned int type, const char *addr);
struct sockaddr *str2sadup(const char *addr);

#ifndef HAVE_SA_LEN
unsigned int compat_sa_len(const struct sockaddr *sa);
#endif
